# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TestSmtpServerResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'connected': 'bool',
        'banner': 'str',
        'tls': 'SmtpTlsDiagnosticResult',
        'auth': 'SmtpAuthDiagnosticResult',
        'transcript': 'list[SmtpDiagnosticStep]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'connected': 'connected',
        'banner': 'banner',
        'tls': 'tls',
        'auth': 'auth',
        'transcript': 'transcript',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, connected=None, banner=None, tls=None, auth=None, transcript=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """TestSmtpServerResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._connected = None
        self._banner = None
        self._tls = None
        self._auth = None
        self._transcript = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.connected = connected
        self.banner = banner
        self.tls = tls
        self.auth = auth
        self.transcript = transcript
        self.warnings = warnings
        self.errors = errors

    @property
    def connected(self):
        """Gets the connected of this TestSmtpServerResults.  # noqa: E501


        :return: The connected of this TestSmtpServerResults.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this TestSmtpServerResults.


        :param connected: The connected of this TestSmtpServerResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and connected is None:  # noqa: E501
            raise ValueError("Invalid value for `connected`, must not be `None`")  # noqa: E501

        self._connected = connected

    @property
    def banner(self):
        """Gets the banner of this TestSmtpServerResults.  # noqa: E501


        :return: The banner of this TestSmtpServerResults.  # noqa: E501
        :rtype: str
        """
        return self._banner

    @banner.setter
    def banner(self, banner):
        """Sets the banner of this TestSmtpServerResults.


        :param banner: The banner of this TestSmtpServerResults.  # noqa: E501
        :type: str
        """

        self._banner = banner

    @property
    def tls(self):
        """Gets the tls of this TestSmtpServerResults.  # noqa: E501


        :return: The tls of this TestSmtpServerResults.  # noqa: E501
        :rtype: SmtpTlsDiagnosticResult
        """
        return self._tls

    @tls.setter
    def tls(self, tls):
        """Sets the tls of this TestSmtpServerResults.


        :param tls: The tls of this TestSmtpServerResults.  # noqa: E501
        :type: SmtpTlsDiagnosticResult
        """
        if self.local_vars_configuration.client_side_validation and tls is None:  # noqa: E501
            raise ValueError("Invalid value for `tls`, must not be `None`")  # noqa: E501

        self._tls = tls

    @property
    def auth(self):
        """Gets the auth of this TestSmtpServerResults.  # noqa: E501


        :return: The auth of this TestSmtpServerResults.  # noqa: E501
        :rtype: SmtpAuthDiagnosticResult
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """Sets the auth of this TestSmtpServerResults.


        :param auth: The auth of this TestSmtpServerResults.  # noqa: E501
        :type: SmtpAuthDiagnosticResult
        """
        if self.local_vars_configuration.client_side_validation and auth is None:  # noqa: E501
            raise ValueError("Invalid value for `auth`, must not be `None`")  # noqa: E501

        self._auth = auth

    @property
    def transcript(self):
        """Gets the transcript of this TestSmtpServerResults.  # noqa: E501


        :return: The transcript of this TestSmtpServerResults.  # noqa: E501
        :rtype: list[SmtpDiagnosticStep]
        """
        return self._transcript

    @transcript.setter
    def transcript(self, transcript):
        """Sets the transcript of this TestSmtpServerResults.


        :param transcript: The transcript of this TestSmtpServerResults.  # noqa: E501
        :type: list[SmtpDiagnosticStep]
        """
        if self.local_vars_configuration.client_side_validation and transcript is None:  # noqa: E501
            raise ValueError("Invalid value for `transcript`, must not be `None`")  # noqa: E501

        self._transcript = transcript

    @property
    def warnings(self):
        """Gets the warnings of this TestSmtpServerResults.  # noqa: E501


        :return: The warnings of this TestSmtpServerResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this TestSmtpServerResults.


        :param warnings: The warnings of this TestSmtpServerResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this TestSmtpServerResults.  # noqa: E501


        :return: The errors of this TestSmtpServerResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this TestSmtpServerResults.


        :param errors: The errors of this TestSmtpServerResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestSmtpServerResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TestSmtpServerResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DmarcReportMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'org_name': 'str',
        'email': 'str',
        'report_id': 'str',
        'domain': 'str',
        'adkim': 'str',
        'aspf': 'str',
        'policy': 'str',
        'subdomain_policy': 'str',
        'percentage': 'int',
        'date_range_begin': 'datetime',
        'date_range_end': 'datetime'
    }

    attribute_map = {
        'org_name': 'orgName',
        'email': 'email',
        'report_id': 'reportId',
        'domain': 'domain',
        'adkim': 'adkim',
        'aspf': 'aspf',
        'policy': 'policy',
        'subdomain_policy': 'subdomainPolicy',
        'percentage': 'percentage',
        'date_range_begin': 'dateRangeBegin',
        'date_range_end': 'dateRangeEnd'
    }

    def __init__(self, org_name=None, email=None, report_id=None, domain=None, adkim=None, aspf=None, policy=None, subdomain_policy=None, percentage=None, date_range_begin=None, date_range_end=None, local_vars_configuration=None):  # noqa: E501
        """DmarcReportMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._org_name = None
        self._email = None
        self._report_id = None
        self._domain = None
        self._adkim = None
        self._aspf = None
        self._policy = None
        self._subdomain_policy = None
        self._percentage = None
        self._date_range_begin = None
        self._date_range_end = None
        self.discriminator = None

        self.org_name = org_name
        self.email = email
        self.report_id = report_id
        self.domain = domain
        self.adkim = adkim
        self.aspf = aspf
        self.policy = policy
        self.subdomain_policy = subdomain_policy
        self.percentage = percentage
        self.date_range_begin = date_range_begin
        self.date_range_end = date_range_end

    @property
    def org_name(self):
        """Gets the org_name of this DmarcReportMetadata.  # noqa: E501


        :return: The org_name of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this DmarcReportMetadata.


        :param org_name: The org_name of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    @property
    def email(self):
        """Gets the email of this DmarcReportMetadata.  # noqa: E501


        :return: The email of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DmarcReportMetadata.


        :param email: The email of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def report_id(self):
        """Gets the report_id of this DmarcReportMetadata.  # noqa: E501


        :return: The report_id of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this DmarcReportMetadata.


        :param report_id: The report_id of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._report_id = report_id

    @property
    def domain(self):
        """Gets the domain of this DmarcReportMetadata.  # noqa: E501


        :return: The domain of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this DmarcReportMetadata.


        :param domain: The domain of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def adkim(self):
        """Gets the adkim of this DmarcReportMetadata.  # noqa: E501


        :return: The adkim of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._adkim

    @adkim.setter
    def adkim(self, adkim):
        """Sets the adkim of this DmarcReportMetadata.


        :param adkim: The adkim of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._adkim = adkim

    @property
    def aspf(self):
        """Gets the aspf of this DmarcReportMetadata.  # noqa: E501


        :return: The aspf of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._aspf

    @aspf.setter
    def aspf(self, aspf):
        """Sets the aspf of this DmarcReportMetadata.


        :param aspf: The aspf of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._aspf = aspf

    @property
    def policy(self):
        """Gets the policy of this DmarcReportMetadata.  # noqa: E501


        :return: The policy of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this DmarcReportMetadata.


        :param policy: The policy of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._policy = policy

    @property
    def subdomain_policy(self):
        """Gets the subdomain_policy of this DmarcReportMetadata.  # noqa: E501


        :return: The subdomain_policy of this DmarcReportMetadata.  # noqa: E501
        :rtype: str
        """
        return self._subdomain_policy

    @subdomain_policy.setter
    def subdomain_policy(self, subdomain_policy):
        """Sets the subdomain_policy of this DmarcReportMetadata.


        :param subdomain_policy: The subdomain_policy of this DmarcReportMetadata.  # noqa: E501
        :type: str
        """

        self._subdomain_policy = subdomain_policy

    @property
    def percentage(self):
        """Gets the percentage of this DmarcReportMetadata.  # noqa: E501


        :return: The percentage of this DmarcReportMetadata.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this DmarcReportMetadata.


        :param percentage: The percentage of this DmarcReportMetadata.  # noqa: E501
        :type: int
        """

        self._percentage = percentage

    @property
    def date_range_begin(self):
        """Gets the date_range_begin of this DmarcReportMetadata.  # noqa: E501


        :return: The date_range_begin of this DmarcReportMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_range_begin

    @date_range_begin.setter
    def date_range_begin(self, date_range_begin):
        """Sets the date_range_begin of this DmarcReportMetadata.


        :param date_range_begin: The date_range_begin of this DmarcReportMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_range_begin = date_range_begin

    @property
    def date_range_end(self):
        """Gets the date_range_end of this DmarcReportMetadata.  # noqa: E501


        :return: The date_range_end of this DmarcReportMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._date_range_end

    @date_range_end.setter
    def date_range_end(self, date_range_end):
        """Sets the date_range_end of this DmarcReportMetadata.


        :param date_range_end: The date_range_end of this DmarcReportMetadata.  # noqa: E501
        :type: datetime
        """

        self._date_range_end = date_range_end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DmarcReportMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DmarcReportMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailFeatureSupportResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'names': 'EmailFeatureNames',
        'detected_features': 'list[str]',
        'feature_overviews': 'list[EmailFeatureOverview]',
        'feature_percentages': 'list[EmailFeatureSupportStatusPercentage]'
    }

    attribute_map = {
        'names': 'names',
        'detected_features': 'detectedFeatures',
        'feature_overviews': 'featureOverviews',
        'feature_percentages': 'featurePercentages'
    }

    def __init__(self, names=None, detected_features=None, feature_overviews=None, feature_percentages=None, local_vars_configuration=None):  # noqa: E501
        """EmailFeatureSupportResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._names = None
        self._detected_features = None
        self._feature_overviews = None
        self._feature_percentages = None
        self.discriminator = None

        self.names = names
        self.detected_features = detected_features
        self.feature_overviews = feature_overviews
        self.feature_percentages = feature_percentages

    @property
    def names(self):
        """Gets the names of this EmailFeatureSupportResult.  # noqa: E501


        :return: The names of this EmailFeatureSupportResult.  # noqa: E501
        :rtype: EmailFeatureNames
        """
        return self._names

    @names.setter
    def names(self, names):
        """Sets the names of this EmailFeatureSupportResult.


        :param names: The names of this EmailFeatureSupportResult.  # noqa: E501
        :type: EmailFeatureNames
        """
        if self.local_vars_configuration.client_side_validation and names is None:  # noqa: E501
            raise ValueError("Invalid value for `names`, must not be `None`")  # noqa: E501

        self._names = names

    @property
    def detected_features(self):
        """Gets the detected_features of this EmailFeatureSupportResult.  # noqa: E501


        :return: The detected_features of this EmailFeatureSupportResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._detected_features

    @detected_features.setter
    def detected_features(self, detected_features):
        """Sets the detected_features of this EmailFeatureSupportResult.


        :param detected_features: The detected_features of this EmailFeatureSupportResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and detected_features is None:  # noqa: E501
            raise ValueError("Invalid value for `detected_features`, must not be `None`")  # noqa: E501
        allowed_values = ["amp", "css-accent-color", "css-align-items", "css-animation", "css-aspect-ratio", "css-at-font-face", "css-at-import", "css-at-keyframes", "css-at-media", "css-at-supports", "css-background-blend-mode", "css-background-clip", "css-background-color", "css-background-image", "css-background-origin", "css-background-position", "css-background-repeat", "css-background-size", "css-background", "css-block-inline-size", "css-border-image", "css-border-inline-block-individual", "css-border-inline-block-longhand", "css-border-inline-block", "css-border-radius-logical", "css-border-radius", "css-border", "css-box-shadow", "css-box-sizing", "css-caption-side", "css-clip-path", "css-column-count", "css-column-layout-properties", "css-direction", "css-display-flex", "css-display-grid", "css-display-none", "css-display", "css-filter", "css-flex-direction", "css-flex-wrap", "css-float", "css-font-kerning", "css-font-weight", "css-font", "css-gap", "css-grid-template", "css-height", "css-hyphens", "css-inline-size", "css-justify-content", "css-left-right-top-bottom", "css-letter-spacing", "css-line-height", "css-list-style-image", "css-list-style-position", "css-list-style-type", "css-list-style", "css-margin-block-start-end", "css-margin-inline-block", "css-margin-inline-start-end", "css-margin-inline", "css-margin", "css-max-block-size", "css-max-height", "css-max-width", "css-min-height", "css-min-inline-size", "css-min-width", "css-mix-blend-mode", "css-object-fit", "css-object-position", "css-opacity", "css-outline-offset", "css-outline", "css-overflow-wrap", "css-overflow", "css-padding-block-start-end", "css-padding-inline-block", "css-padding-inline-start-end", "css-padding", "css-position", "css-tab-size", "css-table-layout", "css-text-align-last", "css-text-align", "css-text-decoration-color", "css-text-decoration-thickness", "css-text-decoration", "css-text-emphasis-position", "css-text-emphasis", "css-text-indent", "css-text-overflow", "css-text-shadow", "css-text-transform", "css-text-underline-offset", "css-transform", "css-vertical-align", "css-visibility", "css-white-space", "css-width", "css-word-break", "css-writing-mode", "css-z-index", "html-abbr", "html-address", "html-align", "html-anchor-links", "html-aria-describedby", "html-aria-hidden", "html-aria-label", "html-aria-labelledby", "html-aria-live", "html-audio", "html-background", "html-base", "html-blockquote", "html-body", "html-button-reset", "html-button-submit", "html-code", "html-del", "html-dfn", "html-dialog", "html-dir", "html-div", "html-doctype", "html-form", "html-h1-h6", "html-height", "html-image-maps", "html-input-checkbox", "html-input-hidden", "html-input-radio", "html-input-reset", "html-input-submit", "html-input-text", "html-lang", "html-link", "html-lists", "html-loading-attribute", "html-mailto-links", "html-marquee", "html-meter", "html-object", "html-p", "html-picture", "html-pre", "html-progress", "html-required", "html-role", "html-rp", "html-rt", "html-ruby", "html-select", "html-semantics", "html-small", "html-span", "html-srcset", "html-strike", "html-strong", "html-style", "html-svg", "html-table", "html-target", "html-textarea", "html-valign", "html-video", "html-wbr", "html-width", "image-avif", "image-base64", "image-bmp", "image-gif", "image-ico", "image-jpg", "image-png", "image-svg", "image-webp", "unsupported"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(detected_features).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `detected_features` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(detected_features) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._detected_features = detected_features

    @property
    def feature_overviews(self):
        """Gets the feature_overviews of this EmailFeatureSupportResult.  # noqa: E501


        :return: The feature_overviews of this EmailFeatureSupportResult.  # noqa: E501
        :rtype: list[EmailFeatureOverview]
        """
        return self._feature_overviews

    @feature_overviews.setter
    def feature_overviews(self, feature_overviews):
        """Sets the feature_overviews of this EmailFeatureSupportResult.


        :param feature_overviews: The feature_overviews of this EmailFeatureSupportResult.  # noqa: E501
        :type: list[EmailFeatureOverview]
        """
        if self.local_vars_configuration.client_side_validation and feature_overviews is None:  # noqa: E501
            raise ValueError("Invalid value for `feature_overviews`, must not be `None`")  # noqa: E501

        self._feature_overviews = feature_overviews

    @property
    def feature_percentages(self):
        """Gets the feature_percentages of this EmailFeatureSupportResult.  # noqa: E501


        :return: The feature_percentages of this EmailFeatureSupportResult.  # noqa: E501
        :rtype: list[EmailFeatureSupportStatusPercentage]
        """
        return self._feature_percentages

    @feature_percentages.setter
    def feature_percentages(self, feature_percentages):
        """Sets the feature_percentages of this EmailFeatureSupportResult.


        :param feature_percentages: The feature_percentages of this EmailFeatureSupportResult.  # noqa: E501
        :type: list[EmailFeatureSupportStatusPercentage]
        """
        if self.local_vars_configuration.client_side_validation and feature_percentages is None:  # noqa: E501
            raise ValueError("Invalid value for `feature_percentages`, must not be `None`")  # noqa: E501

        self._feature_percentages = feature_percentages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailFeatureSupportResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailFeatureSupportResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformMappingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'ai_transform_id': 'str',
        'match_options': 'AIMappingMatchOptions',
        'user_id': 'str',
        'name': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'ai_transform_id': 'aiTransformId',
        'match_options': 'matchOptions',
        'user_id': 'userId',
        'name': 'name',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, ai_transform_id=None, match_options=None, user_id=None, name=None, entity_id=None, entity_type=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """AITransformMappingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ai_transform_id = None
        self._match_options = None
        self._user_id = None
        self._name = None
        self._entity_id = None
        self._entity_type = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.ai_transform_id = ai_transform_id
        self.match_options = match_options
        self.user_id = user_id
        if name is not None:
            self.name = name
        if entity_id is not None:
            self.entity_id = entity_id
        self.entity_type = entity_type
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this AITransformMappingDto.  # noqa: E501


        :return: The id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformMappingDto.


        :param id: The id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this AITransformMappingDto.  # noqa: E501


        :return: The ai_transform_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this AITransformMappingDto.


        :param ai_transform_id: The ai_transform_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def match_options(self):
        """Gets the match_options of this AITransformMappingDto.  # noqa: E501


        :return: The match_options of this AITransformMappingDto.  # noqa: E501
        :rtype: AIMappingMatchOptions
        """
        return self._match_options

    @match_options.setter
    def match_options(self, match_options):
        """Sets the match_options of this AITransformMappingDto.


        :param match_options: The match_options of this AITransformMappingDto.  # noqa: E501
        :type: AIMappingMatchOptions
        """

        self._match_options = match_options

    @property
    def user_id(self):
        """Gets the user_id of this AITransformMappingDto.  # noqa: E501


        :return: The user_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AITransformMappingDto.


        :param user_id: The user_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this AITransformMappingDto.  # noqa: E501


        :return: The name of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformMappingDto.


        :param name: The name of this AITransformMappingDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def entity_id(self):
        """Gets the entity_id of this AITransformMappingDto.  # noqa: E501


        :return: The entity_id of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this AITransformMappingDto.


        :param entity_id: The entity_id of this AITransformMappingDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this AITransformMappingDto.  # noqa: E501


        :return: The entity_type of this AITransformMappingDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AITransformMappingDto.


        :param entity_type: The entity_type of this AITransformMappingDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def created_at(self):
        """Gets the created_at of this AITransformMappingDto.  # noqa: E501


        :return: The created_at of this AITransformMappingDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformMappingDto.


        :param created_at: The created_at of this AITransformMappingDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformMappingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformMappingDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class BounceRecipientProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'status': 'str',
        'sent_email_id': 'str',
        'created_at': 'datetime',
        'recipient': 'str',
        'bounce_type': 'str',
        'action': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'sent_email_id': 'sentEmailId',
        'created_at': 'createdAt',
        'recipient': 'recipient',
        'bounce_type': 'bounceType',
        'action': 'action'
    }

    def __init__(self, id=None, status=None, sent_email_id=None, created_at=None, recipient=None, bounce_type=None, action=None, local_vars_configuration=None):  # noqa: E501
        """BounceRecipientProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._status = None
        self._sent_email_id = None
        self._created_at = None
        self._recipient = None
        self._bounce_type = None
        self._action = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.status = status
        self.sent_email_id = sent_email_id
        self.created_at = created_at
        self.recipient = recipient
        self.bounce_type = bounce_type
        self.action = action

    @property
    def id(self):
        """Gets the id of this BounceRecipientProjection.  # noqa: E501


        :return: The id of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BounceRecipientProjection.


        :param id: The id of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this BounceRecipientProjection.  # noqa: E501


        :return: The status of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BounceRecipientProjection.


        :param status: The status of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def sent_email_id(self):
        """Gets the sent_email_id of this BounceRecipientProjection.  # noqa: E501


        :return: The sent_email_id of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._sent_email_id

    @sent_email_id.setter
    def sent_email_id(self, sent_email_id):
        """Sets the sent_email_id of this BounceRecipientProjection.


        :param sent_email_id: The sent_email_id of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """

        self._sent_email_id = sent_email_id

    @property
    def created_at(self):
        """Gets the created_at of this BounceRecipientProjection.  # noqa: E501


        :return: The created_at of this BounceRecipientProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BounceRecipientProjection.


        :param created_at: The created_at of this BounceRecipientProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def recipient(self):
        """Gets the recipient of this BounceRecipientProjection.  # noqa: E501


        :return: The recipient of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this BounceRecipientProjection.


        :param recipient: The recipient of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and recipient is None:  # noqa: E501
            raise ValueError("Invalid value for `recipient`, must not be `None`")  # noqa: E501

        self._recipient = recipient

    @property
    def bounce_type(self):
        """Gets the bounce_type of this BounceRecipientProjection.  # noqa: E501


        :return: The bounce_type of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._bounce_type

    @bounce_type.setter
    def bounce_type(self, bounce_type):
        """Sets the bounce_type of this BounceRecipientProjection.


        :param bounce_type: The bounce_type of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """

        self._bounce_type = bounce_type

    @property
    def action(self):
        """Gets the action of this BounceRecipientProjection.  # noqa: E501


        :return: The action of this BounceRecipientProjection.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this BounceRecipientProjection.


        :param action: The action of this BounceRecipientProjection.  # noqa: E501
        :type: str
        """

        self._action = action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BounceRecipientProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BounceRecipientProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneNumberReleaseProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'user_id': 'str',
        'phone_country': 'str',
        'created_at': 'datetime',
        'phone_number': 'str',
        'subscription_schedule': 'str',
        'plan_currency': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'user_id': 'userId',
        'phone_country': 'phoneCountry',
        'created_at': 'createdAt',
        'phone_number': 'phoneNumber',
        'subscription_schedule': 'subscriptionSchedule',
        'plan_currency': 'planCurrency'
    }

    def __init__(self, name=None, id=None, user_id=None, phone_country=None, created_at=None, phone_number=None, subscription_schedule=None, plan_currency=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumberReleaseProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._user_id = None
        self._phone_country = None
        self._created_at = None
        self._phone_number = None
        self._subscription_schedule = None
        self._plan_currency = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.id = id
        self.user_id = user_id
        self.phone_country = phone_country
        self.created_at = created_at
        if phone_number is not None:
            self.phone_number = phone_number
        if subscription_schedule is not None:
            self.subscription_schedule = subscription_schedule
        if plan_currency is not None:
            self.plan_currency = plan_currency

    @property
    def name(self):
        """Gets the name of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The name of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhoneNumberReleaseProjection.


        :param name: The name of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The id of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneNumberReleaseProjection.


        :param id: The id of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The user_id of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneNumberReleaseProjection.


        :param user_id: The user_id of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The phone_country of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneNumberReleaseProjection.


        :param phone_country: The phone_country of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def created_at(self):
        """Gets the created_at of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The created_at of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneNumberReleaseProjection.


        :param created_at: The created_at of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The phone_number of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberReleaseProjection.


        :param phone_number: The phone_number of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def subscription_schedule(self):
        """Gets the subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._subscription_schedule

    @subscription_schedule.setter
    def subscription_schedule(self, subscription_schedule):
        """Sets the subscription_schedule of this PhoneNumberReleaseProjection.


        :param subscription_schedule: The subscription_schedule of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["MONTHLY", "YEARLY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and subscription_schedule not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `subscription_schedule` ({0}), must be one of {1}"  # noqa: E501
                .format(subscription_schedule, allowed_values)
            )

        self._subscription_schedule = subscription_schedule

    @property
    def plan_currency(self):
        """Gets the plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501


        :return: The plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501
        :rtype: str
        """
        return self._plan_currency

    @plan_currency.setter
    def plan_currency(self, plan_currency):
        """Sets the plan_currency of this PhoneNumberReleaseProjection.


        :param plan_currency: The plan_currency of this PhoneNumberReleaseProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["EUR", "USD", "JPY", "GBP", "AUD", "CAD", "CHF", "CNY", "INR", "NZD"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and plan_currency not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `plan_currency` ({0}), must be one of {1}"  # noqa: E501
                .format(plan_currency, allowed_values)
            )

        self._plan_currency = plan_currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberReleaseProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumberReleaseProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityFailurePhoneDimensionHotspotDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country': 'str',
        'phone_variant': 'str',
        'failed_run_count': 'int',
        'total_run_count': 'int',
        'failure_rate_percentage': 'float'
    }

    attribute_map = {
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'failed_run_count': 'failedRunCount',
        'total_run_count': 'totalRunCount',
        'failure_rate_percentage': 'failureRatePercentage'
    }

    def __init__(self, phone_country=None, phone_variant=None, failed_run_count=None, total_run_count=None, failure_rate_percentage=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityFailurePhoneDimensionHotspotDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country = None
        self._phone_variant = None
        self._failed_run_count = None
        self._total_run_count = None
        self._failure_rate_percentage = None
        self.discriminator = None

        self.phone_country = phone_country
        self.phone_variant = phone_variant
        self.failed_run_count = failed_run_count
        self.total_run_count = total_run_count
        self.failure_rate_percentage = failure_rate_percentage

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param phone_country: The phone_country of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param phone_variant: The phone_variant of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def failed_run_count(self):
        """Gets the failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_run_count

    @failed_run_count.setter
    def failed_run_count(self, failed_run_count):
        """Sets the failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param failed_run_count: The failed_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_run_count`, must not be `None`")  # noqa: E501

        self._failed_run_count = failed_run_count

    @property
    def total_run_count(self):
        """Gets the total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: int
        """
        return self._total_run_count

    @total_run_count.setter
    def total_run_count(self, total_run_count):
        """Sets the total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param total_run_count: The total_run_count of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_run_count`, must not be `None`")  # noqa: E501

        self._total_run_count = total_run_count

    @property
    def failure_rate_percentage(self):
        """Gets the failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501


        :return: The failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :rtype: float
        """
        return self._failure_rate_percentage

    @failure_rate_percentage.setter
    def failure_rate_percentage(self, failure_rate_percentage):
        """Sets the failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.


        :param failure_rate_percentage: The failure_rate_percentage of this DeliverabilityFailurePhoneDimensionHotspotDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and failure_rate_percentage is None:  # noqa: E501
            raise ValueError("Invalid value for `failure_rate_percentage`, must not be `None`")  # noqa: E501

        self._failure_rate_percentage = failure_rate_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityFailurePhoneDimensionHotspotDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityFailurePhoneDimensionHotspotDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailSignature(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'body': 'str',
        'source': 'str',
        'marker': 'str',
        'detection_type': 'str'
    }

    attribute_map = {
        'body': 'body',
        'source': 'source',
        'marker': 'marker',
        'detection_type': 'detectionType'
    }

    def __init__(self, body=None, source=None, marker=None, detection_type=None, local_vars_configuration=None):  # noqa: E501
        """EmailSignature - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._body = None
        self._source = None
        self._marker = None
        self._detection_type = None
        self.discriminator = None

        self.body = body
        self.source = source
        self.marker = marker
        self.detection_type = detection_type

    @property
    def body(self):
        """Gets the body of this EmailSignature.  # noqa: E501

        Extracted signature text  # noqa: E501

        :return: The body of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EmailSignature.

        Extracted signature text  # noqa: E501

        :param body: The body of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def source(self):
        """Gets the source of this EmailSignature.  # noqa: E501

        Source used for extraction. Examples: RAW_TEXT_PART, RAW_HTML_SELECTOR  # noqa: E501

        :return: The source of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this EmailSignature.

        Source used for extraction. Examples: RAW_TEXT_PART, RAW_HTML_SELECTOR  # noqa: E501

        :param source: The source of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def marker(self):
        """Gets the marker of this EmailSignature.  # noqa: E501

        Matched marker or selector that identified the signature  # noqa: E501

        :return: The marker of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._marker

    @marker.setter
    def marker(self, marker):
        """Sets the marker of this EmailSignature.

        Matched marker or selector that identified the signature  # noqa: E501

        :param marker: The marker of this EmailSignature.  # noqa: E501
        :type: str
        """

        self._marker = marker

    @property
    def detection_type(self):
        """Gets the detection_type of this EmailSignature.  # noqa: E501

        Detection strategy used. Examples: DELIMITER, MOBILE_FOOTER, VALEDICTION  # noqa: E501

        :return: The detection_type of this EmailSignature.  # noqa: E501
        :rtype: str
        """
        return self._detection_type

    @detection_type.setter
    def detection_type(self, detection_type):
        """Sets the detection_type of this EmailSignature.

        Detection strategy used. Examples: DELIMITER, MOBILE_FOOTER, VALEDICTION  # noqa: E501

        :param detection_type: The detection_type of this EmailSignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and detection_type is None:  # noqa: E501
            raise ValueError("Invalid value for `detection_type`, must not be `None`")  # noqa: E501

        self._detection_type = detection_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailSignature):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailSignature):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhonePoolDetailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'name': 'str',
        'description': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'member_count': 'int',
        'available_member_count': 'int',
        'leased_member_count': 'int',
        'members': 'list[PhonePoolMemberDto]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'name': 'name',
        'description': 'description',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'member_count': 'memberCount',
        'available_member_count': 'availableMemberCount',
        'leased_member_count': 'leasedMemberCount',
        'members': 'members'
    }

    def __init__(self, id=None, user_id=None, name=None, description=None, created_at=None, updated_at=None, member_count=None, available_member_count=None, leased_member_count=None, members=None, local_vars_configuration=None):  # noqa: E501
        """PhonePoolDetailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._name = None
        self._description = None
        self._created_at = None
        self._updated_at = None
        self._member_count = None
        self._available_member_count = None
        self._leased_member_count = None
        self._members = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.name = name
        if description is not None:
            self.description = description
        self.created_at = created_at
        self.updated_at = updated_at
        self.member_count = member_count
        self.available_member_count = available_member_count
        self.leased_member_count = leased_member_count
        self.members = members

    @property
    def id(self):
        """Gets the id of this PhonePoolDetailDto.  # noqa: E501


        :return: The id of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhonePoolDetailDto.


        :param id: The id of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhonePoolDetailDto.  # noqa: E501


        :return: The user_id of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhonePoolDetailDto.


        :param user_id: The user_id of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this PhonePoolDetailDto.  # noqa: E501


        :return: The name of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PhonePoolDetailDto.


        :param name: The name of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this PhonePoolDetailDto.  # noqa: E501


        :return: The description of this PhonePoolDetailDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PhonePoolDetailDto.


        :param description: The description of this PhonePoolDetailDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_at(self):
        """Gets the created_at of this PhonePoolDetailDto.  # noqa: E501


        :return: The created_at of this PhonePoolDetailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhonePoolDetailDto.


        :param created_at: The created_at of this PhonePoolDetailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhonePoolDetailDto.  # noqa: E501


        :return: The updated_at of this PhonePoolDetailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhonePoolDetailDto.


        :param updated_at: The updated_at of this PhonePoolDetailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def member_count(self):
        """Gets the member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._member_count

    @member_count.setter
    def member_count(self, member_count):
        """Sets the member_count of this PhonePoolDetailDto.


        :param member_count: The member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `member_count`, must not be `None`")  # noqa: E501

        self._member_count = member_count

    @property
    def available_member_count(self):
        """Gets the available_member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The available_member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._available_member_count

    @available_member_count.setter
    def available_member_count(self, available_member_count):
        """Sets the available_member_count of this PhonePoolDetailDto.


        :param available_member_count: The available_member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and available_member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `available_member_count`, must not be `None`")  # noqa: E501

        self._available_member_count = available_member_count

    @property
    def leased_member_count(self):
        """Gets the leased_member_count of this PhonePoolDetailDto.  # noqa: E501


        :return: The leased_member_count of this PhonePoolDetailDto.  # noqa: E501
        :rtype: int
        """
        return self._leased_member_count

    @leased_member_count.setter
    def leased_member_count(self, leased_member_count):
        """Sets the leased_member_count of this PhonePoolDetailDto.


        :param leased_member_count: The leased_member_count of this PhonePoolDetailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and leased_member_count is None:  # noqa: E501
            raise ValueError("Invalid value for `leased_member_count`, must not be `None`")  # noqa: E501

        self._leased_member_count = leased_member_count

    @property
    def members(self):
        """Gets the members of this PhonePoolDetailDto.  # noqa: E501


        :return: The members of this PhonePoolDetailDto.  # noqa: E501
        :rtype: list[PhonePoolMemberDto]
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this PhonePoolDetailDto.


        :param members: The members of this PhonePoolDetailDto.  # noqa: E501
        :type: list[PhonePoolMemberDto]
        """
        if self.local_vars_configuration.client_side_validation and members is None:  # noqa: E501
            raise ValueError("Invalid value for `members`, must not be `None`")  # noqa: E501

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhonePoolDetailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhonePoolDetailDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProvisioningJobDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'phone_country': 'str',
        'phone_variant': 'str',
        'status': 'str',
        'requested_count': 'int',
        'attempted_count': 'int',
        'succeeded_count': 'int',
        'failed_count': 'int',
        'unavailable_count': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'items': 'list[PhoneProvisioningJobItemDto]'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'status': 'status',
        'requested_count': 'requestedCount',
        'attempted_count': 'attemptedCount',
        'succeeded_count': 'succeededCount',
        'failed_count': 'failedCount',
        'unavailable_count': 'unavailableCount',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'items': 'items'
    }

    def __init__(self, id=None, user_id=None, phone_country=None, phone_variant=None, status=None, requested_count=None, attempted_count=None, succeeded_count=None, failed_count=None, unavailable_count=None, created_at=None, updated_at=None, items=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProvisioningJobDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._phone_country = None
        self._phone_variant = None
        self._status = None
        self._requested_count = None
        self._attempted_count = None
        self._succeeded_count = None
        self._failed_count = None
        self._unavailable_count = None
        self._created_at = None
        self._updated_at = None
        self._items = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.phone_country = phone_country
        if phone_variant is not None:
            self.phone_variant = phone_variant
        self.status = status
        self.requested_count = requested_count
        self.attempted_count = attempted_count
        self.succeeded_count = succeeded_count
        self.failed_count = failed_count
        self.unavailable_count = unavailable_count
        self.created_at = created_at
        self.updated_at = updated_at
        self.items = items

    @property
    def id(self):
        """Gets the id of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The id of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneProvisioningJobDto.


        :param id: The id of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The user_id of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PhoneProvisioningJobDto.


        :param user_id: The user_id of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The phone_country of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneProvisioningJobDto.


        :param phone_country: The phone_country of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The phone_variant of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this PhoneProvisioningJobDto.


        :param phone_variant: The phone_variant of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def status(self):
        """Gets the status of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The status of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PhoneProvisioningJobDto.


        :param status: The status of this PhoneProvisioningJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATED", "RUNNING", "COMPLETED", "PARTIAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def requested_count(self):
        """Gets the requested_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The requested_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._requested_count

    @requested_count.setter
    def requested_count(self, requested_count):
        """Sets the requested_count of this PhoneProvisioningJobDto.


        :param requested_count: The requested_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and requested_count is None:  # noqa: E501
            raise ValueError("Invalid value for `requested_count`, must not be `None`")  # noqa: E501

        self._requested_count = requested_count

    @property
    def attempted_count(self):
        """Gets the attempted_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The attempted_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._attempted_count

    @attempted_count.setter
    def attempted_count(self, attempted_count):
        """Sets the attempted_count of this PhoneProvisioningJobDto.


        :param attempted_count: The attempted_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attempted_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attempted_count`, must not be `None`")  # noqa: E501

        self._attempted_count = attempted_count

    @property
    def succeeded_count(self):
        """Gets the succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._succeeded_count

    @succeeded_count.setter
    def succeeded_count(self, succeeded_count):
        """Sets the succeeded_count of this PhoneProvisioningJobDto.


        :param succeeded_count: The succeeded_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and succeeded_count is None:  # noqa: E501
            raise ValueError("Invalid value for `succeeded_count`, must not be `None`")  # noqa: E501

        self._succeeded_count = succeeded_count

    @property
    def failed_count(self):
        """Gets the failed_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The failed_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this PhoneProvisioningJobDto.


        :param failed_count: The failed_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_count`, must not be `None`")  # noqa: E501

        self._failed_count = failed_count

    @property
    def unavailable_count(self):
        """Gets the unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: int
        """
        return self._unavailable_count

    @unavailable_count.setter
    def unavailable_count(self, unavailable_count):
        """Sets the unavailable_count of this PhoneProvisioningJobDto.


        :param unavailable_count: The unavailable_count of this PhoneProvisioningJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and unavailable_count is None:  # noqa: E501
            raise ValueError("Invalid value for `unavailable_count`, must not be `None`")  # noqa: E501

        self._unavailable_count = unavailable_count

    @property
    def created_at(self):
        """Gets the created_at of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The created_at of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhoneProvisioningJobDto.


        :param created_at: The created_at of this PhoneProvisioningJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The updated_at of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PhoneProvisioningJobDto.


        :param updated_at: The updated_at of this PhoneProvisioningJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def items(self):
        """Gets the items of this PhoneProvisioningJobDto.  # noqa: E501


        :return: The items of this PhoneProvisioningJobDto.  # noqa: E501
        :rtype: list[PhoneProvisioningJobItemDto]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this PhoneProvisioningJobDto.


        :param items: The items of this PhoneProvisioningJobDto.  # noqa: E501
        :type: list[PhoneProvisioningJobItemDto]
        """
        if self.local_vars_configuration.client_side_validation and items is None:  # noqa: E501
            raise ValueError("Invalid value for `items`, must not be `None`")  # noqa: E501

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProvisioningJobDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProvisioningJobDto):
            return True

        return self.to_dict() != other.to_dict()
